@@ -1,7 +1,7 @@
 # flake8: noqa
 from .main import glove
 from .settings import BaseSettings
-from .templates import FoxgloveTemplates
 from .version import VERSION
 
-__all__ = 'BaseSettings', 'glove', 'FoxgloveTemplates', 'VERSION'
+__version__ = VERSION
+__all__ = 'BaseSettings', 'glove', 'VERSION'
